ENVIRONMENTS = [
    "Development",
    "Production",
    "Learn",
    "Staging",  
    ]

APP_ENVIRONMENT_SETTINGS_KEY = "APP_ENVIRONMENT_SETTINGS"

APP_ENVIRONMENT_KEY = "APP_ENVIRONMENT"

SETTINGS_JSON_PATH = "settings.json"

EVENTHUB_CONNECTION_STRING_KEY = "ConnectionString"

EVENTHUB_NAME_KEY = "Name"


