ORDER_WRITTEN_SALE = "OrderWrittenSale"
ORDER_WRITTEN_LAYAWAY = "OrderWrittenLayaway"
ORDER_WRITTEN_QUICK_SALE = "OrderWrittenQuickSale"
ORDER_WRITTEN_QUOTE = "OrderWrittenQuote"

ORDER_DELETED_SALE = "OrderDeletedSale"

FULFILMENT_COMPLETED_CUSTOMER_PICKUP = "FulfillmentCompletedCustomerPickup"
FULFILMENT_COMPLETED_DELIVERY = "FulfillmentCompletedDelivery"
FULFILMENT_COMPLETED_DIRECTSHIP = "FulfillmentCompletedDirectShip"
FULFILMENT_COMPLETED_TAKEWITH = "FulfillmentCompletedTakeWith"

FULFILMENT_SCHEDULED_CUSTOMER_PICKUPY = "FulfillmentScheduledCustomerPickup"
FULFILMENT_SCHEDULED_DELIVERY = "FulfillmentScheduledDelivery"

EVENTS = [
        ORDER_WRITTEN_SALE,
        ORDER_WRITTEN_LAYAWAY,
        ORDER_WRITTEN_QUICK_SALE,
        ORDER_WRITTEN_QUOTE,
        ORDER_DELETED_SALE,    
        FULFILMENT_COMPLETED_CUSTOMER_PICKUP,    
        FULFILMENT_COMPLETED_DELIVERY,    
        FULFILMENT_COMPLETED_DIRECTSHIP,    
        FULFILMENT_COMPLETED_TAKEWITH,    
        FULFILMENT_SCHEDULED_CUSTOMER_PICKUPY,    
        FULFILMENT_SCHEDULED_DELIVERY,    
    ]
